@@ -1,10 +1,42 @@
 import requests
 import os
 import pandas as pd
+from datetime import datetime
+from datetime import timedelta
 from socrata.authorization import Authorization
 from socrata import Socrata
 
 
+def comparison_date(dataframe, date_column):
+    # Calculate Number of years ago for each data point
+    this_year = datetime.now().year
+
+    dataframe['Year'] = this_year - dataframe[date_column].dt.year
+
+    # Determine Number of Unique Years in Dataset
+    years_ago = dataframe['Year'].unique()
+
+    # FORMAT HOUR PRECISION DATE COLUMN
+    dataframe['Session Start Hour'] = pd.to_datetime(dataframe[date_column].dt.strftime('%Y-%m-%d %H:00:00'))
+
+    # COMPARISON DATE
+    dataframe['Comparison Date'] = dataframe['Session Start Hour']
+
+    for number in years_ago:
+        if number > 0:
+            # Check is Current Year is Leap Year and Set Dates Accordingly
+            if datetime.now().year - 1 % 4 == 0:
+                dataframe.loc[dataframe['Year'] == number, 'Comparison Date'] = dataframe[
+                                                                                  'Session Start Hour'] + timedelta(
+                    days=364 - int(number))
+            else:
+                dataframe.loc[dataframe['Year'] == number, 'Comparison Date'] = dataframe[
+                                                                                  'Session Start Hour'] + timedelta(
+                    days=365 - int(number))
+
+    return dataframe['Comparison Date']
+
+
 # RENAME RAMPS FUNCTION
 def rename_ramp(fourfour, column, current_name, replacement, update_config, blanks=False, blank_names=None):
     # GET EXISTING DATA
